@@ -1,14 +1,14 @@
 # -*- coding: utf-8 -*-
 '''Goto - urllib object wrapper'''
 
-__version__ = '0.0.1'
+__version__ = '0.0.2'
 
 
 import sys
 import types
 
-import goto
-import utils
+from . import goto
+from . import utils
 
 
 class CallableModule(types.ModuleType):
